@@ -1,9 +1,6 @@
-
 import typing as tp
 
-
-
-__all__ = ['is_last']
+__all__ = ['is_last', 'add_next', 'half_product', 'group_quantity']
 T = tp.TypeVar('T')
 U = tp.TypeVar('U')
 
