@@ -2,7 +2,6 @@ import collections
 import copy
 import functools
 import heapq
-
 import operator
 import time
 import typing as tp
@@ -10,8 +9,6 @@ from abc import ABCMeta, abstractmethod
 
 from ..decorators import wraps
 
-
-
 T = tp.TypeVar('T')
 Number = tp.Union[int, float]
 
@@ -115,8 +112,8 @@ class Heap(collections.UserList, tp.Generic[T]):
         """
         heapq.heappush(self.data, item)
 
-    def __deepcopy__(self, memodict={}) -> 'Heap':
-        return self.__class__(copy.deepcopy(self.data, memo=memodict))
+    def __deepcopy__(self, memo) -> 'Heap':
+        return self.__class__(copy.deepcopy(self.data, memo))
 
     def __copy__(self) -> 'Heap':
         return self.__class__(copy.copy(self.data))
